@@ -4,10 +4,14 @@ import (
 	"bytes"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
+	"sync"
+	"sync/atomic"
 
 	"github.com/go-errors/errors"
+	log "github.com/sirupsen/logrus"
+	"golang.org/x/sync/errgroup"
 	"google.golang.org/protobuf/proto"
 	"google.golang.org/protobuf/types/known/anypb"
 
@@ -18,21 +22,20 @@ import (
 	"github.com/trufflesecurity/trufflehog/v3/pkg/sources"
 )
 
-const (
-	baseURL = "https://circleci.com/api/v1.1/"
-)
+const baseURL = "https://circleci.com/api/v1.1/"
 
 type Source struct {
 	name     string
+	token    string
 	sourceId int64
 	jobId    int64
 	verify   bool
+	jobPool  *errgroup.Group
 	sources.Progress
-	token  string
 	client *http.Client
 }
 
-// Ensure the Source satisfies the interface at compile time
+// Ensure the Source satisfies the interface at compile time.
 var _ sources.Source = (*Source)(nil)
 
 // Type returns the type of source.
@@ -49,12 +52,14 @@ func (s *Source) JobID() int64 {
 	return s.jobId
 }
 
-// Init returns an initialized Filesystem source.
-func (s *Source) Init(aCtx context.Context, name string, jobId, sourceId int64, verify bool, connection *anypb.Any, _ int) error {
+// Init returns an initialized CircleCI source.
+func (s *Source) Init(_ context.Context, name string, jobId, sourceId int64, verify bool, connection *anypb.Any, concurrency int) error {
 	s.name = name
 	s.sourceId = sourceId
 	s.jobId = jobId
 	s.verify = verify
+	s.jobPool = &errgroup.Group{}
+	s.jobPool.SetLimit(concurrency)
 	s.client = common.RetryableHttpClientTimeout(3)
 
 	var conn sourcespb.CircleCI
@@ -70,34 +75,70 @@ func (s *Source) Init(aCtx context.Context, name string, jobId, sourceId int64,
 	return nil
 }
 
+// scanErrors is used to collect errors encountered while scanning.
+// It ensures that errors are collected in a thread-safe manner.
+type scanErrors struct {
+	count  uint64
+	mu     sync.Mutex
+	errors []error
+}
+
+func newScanErrors(projects int) *scanErrors {
+	return &scanErrors{errors: make([]error, 0, projects)}
+}
+
+func (s *scanErrors) add(err error) {
+	atomic.AddUint64(&s.count, 1)
+	s.mu.Lock()
+	s.errors = append(s.errors, err)
+	s.mu.Unlock()
+}
+
 // Chunks emits chunks of bytes over a channel.
 func (s *Source) Chunks(ctx context.Context, chunksChan chan *sources.Chunk) error {
 	projects, err := s.projects(ctx)
 	if err != nil {
-		return err
+		return fmt.Errorf("error getting projects: %w", err)
 	}
 
-	for _, proj := range projects {
-		builds, err := s.buildsForProject(ctx, proj)
-		if err != nil {
-			return err
-		}
+	var scanned uint64
+	scanErrs := newScanErrors(len(projects))
 
-		for _, bld := range builds {
-			buildSteps, err := s.stepsForBuild(ctx, proj, bld)
+	for _, proj := range projects {
+		proj := proj
+		s.jobPool.Go(func() error {
+			builds, err := s.buildsForProject(ctx, proj)
 			if err != nil {
-				return err
+				scanErrs.add(fmt.Errorf("error getting builds for project %s: %w", proj.RepoName, err))
+				return nil
 			}
 
-			for _, step := range buildSteps {
-				for _, action := range step.Actions {
-					err = s.chunkAction(ctx, proj, bld, action, step.Name, chunksChan)
-					if err != nil {
-						return err
+			for _, bld := range builds {
+				buildSteps, err := s.stepsForBuild(ctx, proj, bld)
+				if err != nil {
+					scanErrs.add(fmt.Errorf("error getting steps for build %d: %w", bld.BuildNum, err))
+					return nil
+				}
+
+				for _, step := range buildSteps {
+					for _, action := range step.Actions {
+						if err = s.chunkAction(ctx, proj, bld, action, step.Name, chunksChan); err != nil {
+							scanErrs.add(fmt.Errorf("error chunking action %v: %w", action, err))
+							return nil
+						}
 					}
 				}
 			}
-		}
+
+			atomic.AddUint64(&scanned, 1)
+			log.Debugf("scanned %d/%d projects", scanned, len(projects))
+			return nil
+		})
+	}
+
+	_ = s.jobPool.Wait()
+	if scanErrs.count > 0 {
+		log.Debugf("encountered %d errors while scanning; errors: %v", scanErrs.count, scanErrs)
 	}
 
 	return nil
@@ -109,7 +150,7 @@ type project struct {
 	RepoName string `json:"reponame"`
 }
 
-func (s *Source) projects(ctx context.Context) ([]project, error) {
+func (s *Source) projects(_ context.Context) ([]project, error) {
 	reqURL := fmt.Sprintf("%sprojects", baseURL)
 	req, err := http.NewRequest("GET", reqURL, nil)
 	if err != nil {
@@ -139,7 +180,7 @@ type build struct {
 	BuildNum int `json:"build_num"`
 }
 
-func (s *Source) buildsForProject(ctx context.Context, proj project) ([]build, error) {
+func (s *Source) buildsForProject(_ context.Context, proj project) ([]build, error) {
 	reqURL := fmt.Sprintf("%sproject/%s/%s/%s", baseURL, proj.VCS, proj.Username, proj.RepoName)
 	req, err := http.NewRequest("GET", reqURL, nil)
 	if err != nil {
@@ -171,7 +212,7 @@ type buildStep struct {
 	Actions []action `json:"actions"`
 }
 
-func (s *Source) stepsForBuild(ctx context.Context, proj project, bld build) ([]buildStep, error) {
+func (s *Source) stepsForBuild(_ context.Context, proj project, bld build) ([]buildStep, error) {
 	reqURL := fmt.Sprintf("%sproject/%s/%s/%s/%d", baseURL, proj.VCS, proj.Username, proj.RepoName, bld.BuildNum)
 	req, err := http.NewRequest("GET", reqURL, nil)
 	if err != nil {
@@ -197,7 +238,7 @@ func (s *Source) stepsForBuild(ctx context.Context, proj project, bld build) ([]
 	return bldRes.Steps, nil
 }
 
-func (s *Source) chunkAction(ctx context.Context, proj project, bld build, act action, stepName string, chunksChan chan *sources.Chunk) error {
+func (s *Source) chunkAction(_ context.Context, proj project, bld build, act action, stepName string, chunksChan chan *sources.Chunk) error {
 	req, err := http.NewRequest("GET", act.OutputURL, nil)
 	if err != nil {
 		return err
@@ -207,7 +248,7 @@ func (s *Source) chunkAction(ctx context.Context, proj project, bld build, act a
 		return err
 	}
 	defer res.Body.Close()
-	logOutput, err := ioutil.ReadAll(res.Body)
+	logOutput, err := io.ReadAll(res.Body)
 	if err != nil {
 		return err
 	}
@@ -240,10 +281,10 @@ func (s *Source) chunkAction(ctx context.Context, proj project, bld build, act a
 }
 
 func removeCircleSha1Line(input []byte) []byte {
-	// Split the input slice into a slice of lines
+	// Split the input slice into a slice of lines.
 	lines := bytes.Split(input, []byte("\n"))
 
-	// Iterate over the lines and add the ones that don't contain "CIRCLE_SHA1=" to the result slice
+	// Iterate over the lines and add the ones that don't contain "CIRCLE_SHA1=" to the result slice.
 	result := make([][]byte, 0, len(lines))
 	for _, line := range lines {
 		if !bytes.Contains(line, []byte("CIRCLE_SHA1=")) {
@@ -251,6 +292,6 @@ func removeCircleSha1Line(input []byte) []byte {
 		}
 	}
 
-	// Join the lines in the result slice and return the resulting slice
+	// Join the lines in the result slice and return the resulting slice.
 	return bytes.Join(result, []byte("\n"))
 }
